@@ -1,4 +1,4 @@
-""" Fix time / date / timezone for photos in Apple Photos """
+"""Fix time / date / timezone for photos in Apple Photos"""
 
 from __future__ import annotations
 
@@ -6,7 +6,7 @@ import datetime
 import sys
 from functools import partial
 from textwrap import dedent
-from typing import Callable
+from typing import Callable, cast
 
 import click
 from rich.console import Console
@@ -20,13 +20,16 @@ from osxphotos.exif_datetime_updater import ExifDateTimeUpdater
 from osxphotos.exiftool import get_exiftool_path
 from osxphotos.photodates import (
     get_photo_date_added,
+    get_photo_date_created,
     reset_photo_date_time_tz,
     set_photo_date_added,
     set_photo_date_from_filename,
+    update_datetime_for_new_timezone,
     update_photo_date_time,
     update_photo_from_function,
     update_photo_time_for_new_timezone,
 )
+from osxphotos.photoquery import load_uuid_from_file
 from osxphotos.phototz import PhotoTimeZone, PhotoTimeZoneUpdater
 from osxphotos.platform import assert_macos
 from osxphotos.timezones import Timezone
@@ -44,7 +47,7 @@ from .click_rich_echo import rich_echo_error as echo_error
 from .color_themes import get_theme
 from .common import OSXPHOTOS_CRASH_LOG
 from .darkmode import is_dark_mode
-from .help import HELP_WIDTH, rich_text
+from .help import HELP_WIDTH, filter_help_text_for_sphinx, is_sphinx_running, rich_text
 from .param_types import (
     DateOffset,
     DateTimeISO8601,
@@ -77,15 +80,13 @@ class TimeWarpCommand(click.Command):
 
 Timewarp operates on photos selected in Apple Photos.  To use it, open Photos, select the photos for which you'd like to adjust the date/time/timezone, then run osxphotos timewarp from the command line:
 
-`osxphotos timewarp --date 2021-09-10 --time-delta "-1 hour" --timezone -0700 --verbose`
+'osxphotos timewarp --date 2021-09-10 --time-delta "-1 hour" --timezone -0700 --verbose'
 
 A named timezone can also be specified:
 
-`osxphotos timewarp --date 2021-09-10 --time-delta "-1 hour" --timezone "America/Los_Angeles" --verbose`
+'osxphotos timewarp --date 2021-09-10 --time-delta "-1 hour" --timezone "America/Los_Angeles" --verbose'
 
-This example sets the date for all selected photos to `2021-09-10`, subtracts 1 hour from the time of each photo, and sets the timezone of each photo to `GMT -07:00` (Pacific Daylight Time).
-
-osxphotos timewarp has been well tested on macOS Catalina (10.15).  It should work on macOS Big Sur (11.0) and macOS Monterey (12.0) but I have not been able to test this.  It will not work on macOS Mojave (10.14) or earlier as the Photos database format is different.
+This example sets the date for all selected photos to '2021-09-10', subtracts 1 hour from the time of each photo, and sets the timezone of each photo to 'GMT -07:00' (Pacific Daylight Time).
 
 **Caution**: This app directly modifies your Photos library database using undocumented features.  It may corrupt, damage, or destroy your Photos library.  Use at your own caution.  I strongly recommend you make a backup of your Photos library before using this script (e.g. use Time Machine).
 
@@ -93,56 +94,56 @@ osxphotos timewarp has been well tested on macOS Catalina (10.15).  It should wo
 
 **Add 1 day to the date of each photo**
 
-`osxphotos timewarp --date-delta 1`
+'osxphotos timewarp --date-delta 1'
 
 or
 
-`osxphotos timewarp --date-delta "+1 day"`
+'osxphotos timewarp --date-delta "+1 day"'
 
 **Set the date of each photo to 23 April 2020 and add 3 hours to the time**
 
-`osxphotos timewarp --date 2020-04-23 --time-delta "+3 hours"`
+'osxphotos timewarp --date 2020-04-23 --time-delta "+3 hours"'
 
 or
 
-`osxphotos timewarp --date 2020-04-23 --time-delta "+03:00:00"`
+'osxphotos timewarp --date 2020-04-23 --time-delta "+03:00:00"'
 
 **Set the time of each photo to 14:30 and set the timezone to UTC +1:00 (Central European Time)**
 
-`osxphotos timewarp --time 14:30 --timezone +01:00`
+'osxphotos timewarp --time 14:30 --timezone +01:00'
 
 or
 
-`osxphotos timewarp --time 14:30 --timezone +0100`
+'osxphotos timewarp --time 14:30 --timezone +0100'
 
 **Subtract 1 week from the date for each photo, add 3 hours to the time, set the timezone to UTC -07:00 (Pacific Daylight Time) and also use exiftool to update the EXIF metadata accordingly in the original file; use --verbose to print additional details**
 
-`osxphotos timewarp --date-delta "-1 week" --time-delta "+3 hours" --timezone -0700 --push-exif --verbose`
+'osxphotos timewarp --date-delta "-1 week" --time-delta "+3 hours" --timezone -0700 --push-exif --verbose'
 
-For this to work, you'll need to install the third-party exiftool (https://exiftool.org/) utility.  If you use  homebrew (https://brew.sh/) you can do this with `brew install exiftool`.
+For this to work, you'll need to install the third-party exiftool (https://exiftool.org/) utility.  If you use  homebrew (https://brew.sh/) you can do this with 'brew install exiftool'.
 
 **Set the timezone to UTC +03:00 for each photo but keep the time the same (that is, don't adjust time for the new timezone)**
 
-`osxphotos timewarp --timezone 0300 --match-time`
+'osxphotos timewarp --timezone 0300 --match-time'
 
-*Note on timezones and times*: In Photos, when you change the timezone, Photos assumes the time itself was correct for the previous timezone and adjusts the time accordingly to the new timezone.  E.g. if the photo's time is `13:00` and the timezone is `GMT -07:00` and you adjust the timezone one hour east to `GMT -06:00`, Photos will change the time of the photo to `14:00`.  osxphotos timewarp follows this behavior.  Using `--match-time` allows you to adjust the timezone but keep the same time without adjustment. For example, if your camera clock was correct but lacked timezone information and you took photos in one timezone but imported them to photos in another, Photos will add the timezone of the computer at time of import.  You can use osxphotos timewarp to adjust the timezone but keep the time using `--match-time`.
+*Note on timezones and times*: In Photos, when you change the timezone, Photos assumes the time itself was correct for the previous timezone and adjusts the time accordingly to the new timezone.  E.g. if the photo's time is '13:00' and the timezone is 'GMT -07:00' and you adjust the timezone one hour east to 'GMT -06:00', Photos will change the time of the photo to '14:00'.  osxphotos timewarp follows this behavior.  Using '--match-time' allows you to adjust the timezone but keep the same time without adjustment. For example, if your camera clock was correct but lacked timezone information and you took photos in one timezone but imported them to photos in another, Photos will add the timezone of the computer at time of import.  You can use osxphotos timewarp to adjust the timezone but keep the time using '--match-time'.
 
 **Update the date the photos were added to Photos**
 
-`osxphotos timewarp --date-added 2021-09-10`
+'osxphotos timewarp --date-added 2021-09-10'
 
 **Update the date the photos were added to Photos to match the date of the photo**
 
-`osxphotos timewarp --date-added-from-photo`
+'osxphotos timewarp --date-added-from-photo'
 
 **Compare the date/time/timezone of selected photos with the date/time/timezone in the photos' original EXIF metadata**
 
-`osxphotos timewarp --compare-exif`
+'osxphotos timewarp --compare-exif'
 
 **Read the date/time/timezone from the photos' original EXIF metadata to update the photos' date/time/timezone;
 if the EXIF data is missing, use the file modification date/time; show verbose output**
 
-`osxphotos timewarp --pull-exif --use-file-time --verbose`
+'osxphotos timewarp --pull-exif --use-file-time --verbose'
 
 ## Parsing Dates/Times from Filenames
 
@@ -150,8 +151,8 @@ The --parse-date option allows you to parse dates/times from the original filena
 This is useful if you files with dates/times embedded in the filename but not in the metadata.
 
 
-The argument to `--parse-date` is a pattern string that is used to parse the date/time
-from the filename. The pattern string is a superset of the python `strftime/strptime`
+The argument to '--parse-date' is a pattern string that is used to parse the date/time
+from the filename. The pattern string is a superset of the python 'strftime/strptime'
 format with the following additions:
 
 - *: Match any number of characters
@@ -160,8 +161,8 @@ format with the following additions:
 - {n}: Match exactly n characters
 - {n,}: Match at least n characters
 - {n,m}: Match at least n characters and at most m characters
-- In addition to `%%` for a literal `%`, the following format codes are supported:
-    `%^`, `%$`, `%*`, `%|`, `%{`, `%}` for `^`, `$`, `*`, `|`, `{`, `}` respectively
+- In addition to '%%' for a literal '%', the following format codes are supported:
+    '%^', '%$', '%*', '%|', '%{', '%}' for '^', '$', '*', '|', '{', '}' respectively
 - |: join multiple format codes; each code is tried in order until one matches
 - Unlike the standard library, the leading zero is not optional for
     %d, %m, %H, %I, %M, %S, %j, %U, %W, and %V
@@ -170,12 +171,6 @@ format with the following additions:
 For more information on strptime format codes, see:
 https://docs.python.org/3/library/datetime.html?highlight=strptime#strftime-and-strptime-format-codes
 
-**Note**: The time zone of the parsed date/time is assumed to be the local time zone.
-If the parse pattern includes a time zone, the photo's time will be converted from
-the specified time zone to the local time zone. The timewarp command does not currently
-setting the timezone when parsing the filename.
-
-
 """  # noqa: E501
                 ),
                 width=formatter.width,
@@ -183,6 +178,11 @@ setting the timezone when parsing the filename.
             )
         )
         help_text += formatter.getvalue()
+
+        # If Sphinx is running, filter all help text for RST compatibility
+        if is_sphinx_running():
+            help_text = filter_help_text_for_sphinx(help_text)
+
         return help_text
 
 
@@ -199,8 +199,7 @@ setting the timezone when parsing the filename.
     "-D",
     metavar="DELTA",
     type=DateOffset(),
-    help="Adjust date for selected photos by DELTA. "
-    "Format is one of: '±D days', '±W weeks', '±D' where D is days",
+    help="Adjust date for selected photos by DELTA. Format is one of: '±D days', '±W weeks', '±D' where D is days",
 )
 @click.option(
     "--time",
@@ -214,8 +213,7 @@ setting the timezone when parsing the filename.
     "-T",
     metavar="DELTA",
     type=TimeOffset(),
-    help="Adjust time for selected photos by DELTA time. "
-    "Format is one of '±HH:MM:SS', '±H hours' (or hr), '±M minutes' (or min), '±S seconds' (or sec), '±S' (where S is seconds)",
+    help="Adjust time for selected photos by DELTA time. Format is one of '±HH:MM:SS', '±H hours' (or hr), '±M minutes' (or min), '±S seconds' (or sec), '±S' (where S is seconds)",
 )
 @click.option(
     "--timezone",
@@ -251,18 +249,13 @@ setting the timezone when parsing the filename.
 @click.option(
     "--date-added-from-photo",
     is_flag=True,
-    help="Set date/time added for selected photos to the date/time the photo was taken. "
-    "This changes the date added or imported date in Photos but "
-    "does not change the date/time/timezone of the photo itself. "
-    "The date/time added will be converted from the photo's timezone to the local time zone. ",
+    help="Set date/time added for selected photos to the date/time the photo was taken. This changes the date added or imported date in Photos but does not change the date/time/timezone of the photo itself. The date/time added will be converted from the photo's timezone to the local time zone. ",
 )
 @click.option(
     "--reset",
     "-R",
     is_flag=True,
-    help="Reset date/time/timezone for selected photos to the original values. "
-    "This only works on macOS >= 13.0 (Ventura). Photos imported on older versions of macOS may not "
-    "have an original date/time stored in the Photos database so the command will have no effect for these photos.",
+    help="Reset date/time/timezone for selected photos to the original values. This only works on macOS >= 13.0 (Ventura). Photos imported on older versions of macOS may not have an original date/time stored in the Photos database so the command will have no effect for these photos.",
 )
 @click.option(
     "--inspect",
@@ -274,9 +267,7 @@ setting the timezone when parsing the filename.
     "--compare-exif",
     "-c",
     is_flag=True,
-    help="Compare the EXIF date/time/timezone for each selected photo to the same data in Photos. "
-    "Requires the third-party exiftool utility be installed (see https://exiftool.org/). "
-    "See also --add-to-album.",
+    help="Compare the EXIF date/time/timezone for each selected photo to the same data in Photos. Requires the third-party exiftool utility be installed (see https://exiftool.org/). See also --add-to-album.",
 )
 @click.option(
     "--push-exif",
@@ -355,15 +346,13 @@ setting the timezone when parsing the filename.
     "--use-file-time",
     "-f",
     is_flag=True,
-    help="When used with --pull-exif, the file modification date/time will be used if date/time "
-    "is missing from the EXIF data. ",
+    help="When used with --pull-exif, the file modification date/time will be used if date/time is missing from the EXIF data. ",
 )
 @click.option(
     "--add-to-album",
     "-a",
     metavar="ALBUM",
-    help="When used with --compare-exif, adds any photos with date/time/timezone differences "
-    "between Photos/EXIF to album ALBUM.  If ALBUM does not exist, it will be created.",
+    help="When used with --compare-exif, adds any photos with date/time/timezone differences between Photos/EXIF to album ALBUM.  If ALBUM does not exist, it will be created.",
 )
 @click.option(
     "--uuid",
@@ -371,8 +360,7 @@ setting the timezone when parsing the filename.
     metavar="UUID",
     default=None,
     multiple=True,
-    help="Apple to photo(s) with UUID(s). "
-    "May be repeated to include multiple UUIDs.",
+    help="Apple to photo(s) with UUID(s). May be repeated to include multiple UUIDs.",
 )
 @click.option(
     "--uuid-from-file",
@@ -380,9 +368,7 @@ setting the timezone when parsing the filename.
     metavar="FILE",
     default=None,
     multiple=False,
-    help="Apply to photos with UUID(s) loaded from FILE. "
-    "Format is a single UUID per line. Lines preceded with # are ignored. "
-    "If FILE is '-', read UUIDs from stdin.",
+    help="Apply to photos with UUID(s) loaded from FILE. Format is a single UUID per line. Lines preceded with # are ignored. If FILE is '-', read UUIDs from stdin.",
     type=PathOrStdin(exists=True),
 )
 @VERBOSE_OPTION
@@ -402,7 +388,6 @@ setting the timezone when parsing the filename.
     type=click.Path(exists=True),
     help="Optional path to exiftool executable (will look in $PATH if not specified) for those options which require exiftool.",
 )
-@click.option("--timestamp", is_flag=True, help="Add time stamp to verbose output")
 @THEME_OPTION
 @click.option(
     "--plain",
@@ -451,7 +436,9 @@ def timewarp(
 ):
     """Adjust date/time/timezone of photos in Apple Photos.
 
-    Changes will be applied to all photos currently selected in Photos.
+    Changes will be applied to: 1) photos specified via --uuid and
+    --uuid-from-file 2) photos currently selected in Photos in 'All Photos'
+    or Album views 3) all photos in Album view, if no selection is made.
     timewarp cannot operate on photos selected in a Smart Album;
     select photos in a regular album or in the 'All Photos' view.
     See Timewarp Overview below for additional information.
@@ -495,8 +482,8 @@ def timewarp_cli(
     If you want to call the timewarp function directly in your own code, you may call
     timewarp_cli() directly. In this case you will be responsible for ensuring that all
     arguments are passed and all arguments are of the correct type. For example, the
-    CLI argument `--date` converts user input in form `2023-01-01` to a
-    datetime.datetime object. If passing `date`, you will be responsible for
+    CLI argument '--date' converts user input in form '2023-01-01' to a
+    datetime.datetime object. If passing 'date', you will be responsible for
     passing a datetime.datetime not the ISO string as is done on the command line.
 
     Returns: 1 if error or 0 if no error
@@ -524,10 +511,7 @@ def timewarp_cli(
         ]
     ):
         raise click.UsageError(
-            "At least one of --date, --date-delta, --time, --time-delta, "
-            "--timezone, --inspect, --compare-exif, --push-exif, --pull-exif, "
-            "--parse-date, --reset, --function, --date-added, or --date-added-from-photo "
-            "must be specified."
+            "At least one of --date, --date-delta, --time, --time-delta, --timezone, --inspect, --compare-exif, --push-exif, --pull-exif, --parse-date, --reset, --function, --date-added, or --date-added-from-photo must be specified."
         )
 
     if inspect and compare_exif:
@@ -560,23 +544,29 @@ def timewarp_cli(
     if uuid:
         photos.extend(list(PhotosLibrary().photos(uuid=uuid)))
     if uuid_from_file:
-        photos.extend(list(PhotosLibrary().photos(uuid=uuid_from_file)))
-    try:
-        photos.extend(PhotosLibrary().selection)
-    except Exception as e:
-        # AppleScript error -1728 occurs if user attempts to get selected photos in a Smart Album
-        if "(-1728)" in str(e):
-            echo_error(
-                "[error]Could not get selected photos. Ensure photos is open and photos are selected. "
-                "If you have selected photos and you see this message, it may be because the selected photos are in a Photos Smart Album. "
-                f"{APP_NAME} cannot access photos in a Smart Album.  Select the photos in a regular album or in 'All Photos' view. "
-                "Another option is to create a new album using 'File | New Album With Selection' then select the photos in the new album.[/]",
-            )
-        else:
-            echo_error(
-                f"[error]Could not get selected photos. Ensure Photos is open and photos to process are selected. {e}[/]",
-            )
-        return 1
+        photos.extend(
+            list(PhotosLibrary().photos(uuid=load_uuid_from_file(uuid_from_file)))
+        )
+
+    # If neither uuid nor uuid_from_file is specified, then operate over selected photos
+    if not (uuid or uuid_from_file):
+        try:
+            photos.extend(PhotosLibrary().selection)
+        except Exception as e:
+            # AppleScript error -1728 occurs if user attempts to get selected photos in a Smart Album
+            if "(-1728)" in str(e):
+                echo_error(
+                    "[error]Could not get selected photos. Ensure photos is open and photos are selected. "
+                    "If you have selected photos and you see this message, it may be because the selected photos are in a Photos Smart Album. "
+                    f"{APP_NAME} cannot access photos in a Smart Album.  Select the photos in a regular album or in 'All Photos' view. "
+                    "Another option is to create a new album using 'File | New Album With Selection' then select the photos in the new album.[/]",
+                )
+            else:
+                echo_error(
+                    f"[error]Could not get selected photos. Ensure Photos is open and photos to process are selected. {e}[/]",
+                )
+            return 1
+
     if not photos:
         echo_error("[warning]No photos selected[/]")
         return 0
@@ -636,6 +626,7 @@ def timewarp_cli(
         set_photo_date_from_filename,
         library_path=library,
         verbose=verbose,
+        set_timezone=True,
     )
 
     set_photo_date_added_ = partial(
@@ -676,11 +667,7 @@ def timewarp_cli(
         tzinfo = PhotoTimeZone(library_path=library)
         if photos:
             echo(
-                "[filename]filename[/filename], [uuid]uuid[/uuid], "
-                "[time]photo time (local)[/time], "
-                "[time]photo time[/time], "
-                "[tz]timezone offset[/tz], [tz]timezone name[/tz], "
-                "[time]date added (local)[/time]"
+                "[filename]filename[/filename], [uuid]uuid[/uuid], [time]photo time (local)[/time], [time]photo time[/time], [tz]timezone offset[/tz], [tz]timezone name[/tz], [time]date added (local)[/time]"
             )
         for photo in photos:
             set_crash_data("photo", f"{photo.uuid} {photo.filename}")
@@ -689,11 +676,7 @@ def timewarp_cli(
             photo_date_tz = datetime_to_new_tz(photo_date_local, tz_seconds)
             date_added = get_photo_date_added_(photo)
             echo(
-                f"[filename]{photo.filename}[/filename], [uuid]{photo.uuid}[/uuid], "
-                f"[time]{photo_date_local.strftime(DATETIME_FORMAT)}[/time], "
-                f"[time]{photo_date_tz.strftime(DATETIME_FORMAT)}[/time], "
-                f"[tz]{tz_str}[/tz], [tz]{tz_name}[/tz], "
-                f"[time]{date_added.strftime(DATETIME_FORMAT)}[/time]"
+                f"[filename]{photo.filename}[/filename], [uuid]{photo.uuid}[/uuid], [time]{photo_date_local.strftime(DATETIME_FORMAT)}[/time], [time]{photo_date_tz.strftime(DATETIME_FORMAT)}[/time], [tz]{tz_str}[/tz], [tz]{tz_name}[/tz], [time]{date_added.strftime(DATETIME_FORMAT)}[/time]"
             )
         return 0
 
@@ -734,15 +717,11 @@ def timewarp_cli(
                     verbose(f"Photo {filename} ({uuid}) has same date/time/timezone")
             else:
                 echo(
-                    f"{filename}, {uuid}, "
-                    f"{diff_results.photos_date} {diff_results.photos_time}, {diff_results.exif_date} {diff_results.exif_time}, "
-                    f"{diff_results.photos_tz}, {diff_results.exif_tz}"
+                    f"{filename}, {uuid}, {diff_results.photos_date} {diff_results.photos_time}, {diff_results.exif_date} {diff_results.exif_time}, {diff_results.photos_tz}, {diff_results.exif_tz}"
                 )
         if album:
             echo(
-                f"Compared {len(photos)} photos, found {different_photos} "
-                f"that {pluralize(different_photos, 'is', 'are')} different and "
-                f"added {pluralize(different_photos, 'it', 'them')} to album '{album.name}'."
+                f"Compared {len(photos)} photos, found {different_photos} that {pluralize(different_photos, 'is', 'are')} different and added {pluralize(different_photos, 'it', 'them')} to album '{album.name}'."
             )
         return 0
 
@@ -779,16 +758,23 @@ def timewarp_cli(
                 )
             if any([date, time, date_delta, time_delta]):
                 update_photo_date_time_(photo=photo)
-            if match_time:
-                # need to adjust time before the timezone is updated
-                # or the old timezone will be overwritten in the database
-                update_photo_time_for_new_timezone_(photo=photo, new_timezone=timezone)
-            if timezone:
-                tz_updater.update_photo(photo)
             if date_added:
                 set_photo_date_added_(photo)
             if date_added_from_photo:
                 set_photo_date_added_from_photo_(photo, date_added=photo.date)
+            if timezone:
+                previous_photo_date = get_photo_date_created(photo)
+                tz_updater.update_photo(photo)
+                if match_time:
+                    update_photo_date_time(
+                        library_path=library,
+                        photo=photo,
+                        date=previous_photo_date.date(),
+                        time=previous_photo_date.time(),
+                        date_delta=None,
+                        time_delta=None,
+                        verbose=verbose,
+                    )
             if function:
                 verbose(f"Calling function [bold]{function[1]}")
                 photo_path = exif_updater.get_photo_path(photo)
